/* Webcamoid, webcam capture application.
 * Copyright (C) 2023  Gonzalo Exequiel Pedone
 *
 * Webcamoid is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Webcamoid is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Webcamoid. If not, see <http://www.gnu.org/licenses/>.
 *
 * Web-Site: http://webcamoid.github.io/
 */

#include <QGuiApplication>

#include "plugin.h"
#include "xlibdev.h"

#ifdef Q_OS_UNIX
#include <X11/Xlib.h>
#endif

bool Plugin::canLoad()
{
    if (qApp->platformName() == "wayland")
        return false;

#ifdef Q_OS_UNIX
    auto display = XOpenDisplay(nullptr);

     if (!display)
         return false;

    XCloseDisplay(display);
#endif

    return true;
}

QObject *Plugin::create()
{
    return new XlibDev();
}

#include "moc_plugin.cpp"
